# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/labelingpipelinerun/v1/labelingpipelinerun.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nWgithub.com/metaprov/modelaapi/services/labelingpipelinerun/v1/labelingpipelinerun.proto\x12=github.com.metaprov.modelaapi.services.labelingpipelinerun.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\x96\x02\n\x1eListLabelingPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12y\n\x06labels\x18\x02 \x03(\x0b\x32i.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa7\x01\n\x1fListLabelingPipelineRunResponse\x12k\n\x14labelingpipelineruns\x18\x01 \x01(\x0b\x32M.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRunList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8a\x01\n CreateLabelingPipelineRunRequest\x12\x66\n\x13labelingpipelinerun\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\"#\n!CreateLabelingPipelineRunResponse\"\xba\x01\n UpdateLabelingPipelineRunRequest\x12\x66\n\x13labelingpipelinerun\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"#\n!UpdateLabelingPipelineRunResponse\"@\n\x1dGetLabelingPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x96\x01\n\x1eGetLabelingPipelineRunResponse\x12\x66\n\x13labelingpipelinerun\x18\x01 \x01(\x0b\x32I.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.LabelingPipelineRun\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"C\n DeleteLabelingPipelineRunRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"#\n!DeleteLabelingPipelineRunResponse2\xa2\x0b\n\x1aLabelingPipelineRunService\x12\x87\x02\n\x18ListLabelingPipelineRuns\x12].github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest\x1a^.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunResponse\",\x82\xd3\xe4\x93\x02&\x12$/v1/labelingpipelineruns/{namespace}\x12\x83\x02\n\x19\x43reateLabelingPipelineRun\x12_.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.CreateLabelingPipelineRunRequest\x1a`.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.CreateLabelingPipelineRunResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1/labelingpipelineruns:\x01*\x12\x8a\x02\n\x16GetLabelingPipelineRun\x12\\.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunRequest\x1a].github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunResponse\"3\x82\xd3\xe4\x93\x02-\x12+/v1/labelingpipelineruns/{namespace}/{name}\x12\xd0\x02\n\x19UpdateLabelingPipelineRun\x12_.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.UpdateLabelingPipelineRunRequest\x1a`.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.UpdateLabelingPipelineRunResponse\"p\x82\xd3\xe4\x93\x02j\x1a\x65/v1/labelingpipelineruns/{labelingpipelinerun.metadata.namespace}/{labelingpipelinerun.metadata.name}:\x01*\x12\x93\x02\n\x19\x44\x65leteLabelingPipelineRun\x12_.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.DeleteLabelingPipelineRunRequest\x1a`.github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.DeleteLabelingPipelineRunResponse\"3\x82\xd3\xe4\x93\x02-*+/v1/labelingpipelineruns/{namespace}/{name}B?Z=github.com/metaprov/modelaapi/services/labelingpipelinerun/v1b\x06proto3')



_LISTLABELINGPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['ListLabelingPipelineRunRequest']
_LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY = _LISTLABELINGPIPELINERUNREQUEST.nested_types_by_name['LabelsEntry']
_LISTLABELINGPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['ListLabelingPipelineRunResponse']
_CREATELABELINGPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['CreateLabelingPipelineRunRequest']
_CREATELABELINGPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['CreateLabelingPipelineRunResponse']
_UPDATELABELINGPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['UpdateLabelingPipelineRunRequest']
_UPDATELABELINGPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['UpdateLabelingPipelineRunResponse']
_GETLABELINGPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['GetLabelingPipelineRunRequest']
_GETLABELINGPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['GetLabelingPipelineRunResponse']
_DELETELABELINGPIPELINERUNREQUEST = DESCRIPTOR.message_types_by_name['DeleteLabelingPipelineRunRequest']
_DELETELABELINGPIPELINERUNRESPONSE = DESCRIPTOR.message_types_by_name['DeleteLabelingPipelineRunResponse']
ListLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('ListLabelingPipelineRunRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTLABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(ListLabelingPipelineRunRequest)
_sym_db.RegisterMessage(ListLabelingPipelineRunRequest.LabelsEntry)

ListLabelingPipelineRunResponse = _reflection.GeneratedProtocolMessageType('ListLabelingPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLABELINGPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.ListLabelingPipelineRunResponse)
  })
_sym_db.RegisterMessage(ListLabelingPipelineRunResponse)

CreateLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('CreateLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.CreateLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(CreateLabelingPipelineRunRequest)

CreateLabelingPipelineRunResponse = _reflection.GeneratedProtocolMessageType('CreateLabelingPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATELABELINGPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.CreateLabelingPipelineRunResponse)
  })
_sym_db.RegisterMessage(CreateLabelingPipelineRunResponse)

UpdateLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('UpdateLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.UpdateLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(UpdateLabelingPipelineRunRequest)

UpdateLabelingPipelineRunResponse = _reflection.GeneratedProtocolMessageType('UpdateLabelingPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATELABELINGPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.UpdateLabelingPipelineRunResponse)
  })
_sym_db.RegisterMessage(UpdateLabelingPipelineRunResponse)

GetLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('GetLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETLABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(GetLabelingPipelineRunRequest)

GetLabelingPipelineRunResponse = _reflection.GeneratedProtocolMessageType('GetLabelingPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETLABELINGPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.GetLabelingPipelineRunResponse)
  })
_sym_db.RegisterMessage(GetLabelingPipelineRunResponse)

DeleteLabelingPipelineRunRequest = _reflection.GeneratedProtocolMessageType('DeleteLabelingPipelineRunRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABELINGPIPELINERUNREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.DeleteLabelingPipelineRunRequest)
  })
_sym_db.RegisterMessage(DeleteLabelingPipelineRunRequest)

DeleteLabelingPipelineRunResponse = _reflection.GeneratedProtocolMessageType('DeleteLabelingPipelineRunResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETELABELINGPIPELINERUNRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.labelingpipelinerun_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.labelingpipelinerun.v1.DeleteLabelingPipelineRunResponse)
  })
_sym_db.RegisterMessage(DeleteLabelingPipelineRunResponse)

_LABELINGPIPELINERUNSERVICE = DESCRIPTOR.services_by_name['LabelingPipelineRunService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z=github.com/metaprov/modelaapi/services/labelingpipelinerun/v1'
  _LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY._options = None
  _LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _LABELINGPIPELINERUNSERVICE.methods_by_name['ListLabelingPipelineRuns']._options = None
  _LABELINGPIPELINERUNSERVICE.methods_by_name['ListLabelingPipelineRuns']._serialized_options = b'\202\323\344\223\002&\022$/v1/labelingpipelineruns/{namespace}'
  _LABELINGPIPELINERUNSERVICE.methods_by_name['CreateLabelingPipelineRun']._options = None
  _LABELINGPIPELINERUNSERVICE.methods_by_name['CreateLabelingPipelineRun']._serialized_options = b'\202\323\344\223\002\035\"\030/v1/labelingpipelineruns:\001*'
  _LABELINGPIPELINERUNSERVICE.methods_by_name['GetLabelingPipelineRun']._options = None
  _LABELINGPIPELINERUNSERVICE.methods_by_name['GetLabelingPipelineRun']._serialized_options = b'\202\323\344\223\002-\022+/v1/labelingpipelineruns/{namespace}/{name}'
  _LABELINGPIPELINERUNSERVICE.methods_by_name['UpdateLabelingPipelineRun']._options = None
  _LABELINGPIPELINERUNSERVICE.methods_by_name['UpdateLabelingPipelineRun']._serialized_options = b'\202\323\344\223\002j\032e/v1/labelingpipelineruns/{labelingpipelinerun.metadata.namespace}/{labelingpipelinerun.metadata.name}:\001*'
  _LABELINGPIPELINERUNSERVICE.methods_by_name['DeleteLabelingPipelineRun']._options = None
  _LABELINGPIPELINERUNSERVICE.methods_by_name['DeleteLabelingPipelineRun']._serialized_options = b'\202\323\344\223\002-*+/v1/labelingpipelineruns/{namespace}/{name}'
  _LISTLABELINGPIPELINERUNREQUEST._serialized_start=289
  _LISTLABELINGPIPELINERUNREQUEST._serialized_end=567
  _LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY._serialized_start=522
  _LISTLABELINGPIPELINERUNREQUEST_LABELSENTRY._serialized_end=567
  _LISTLABELINGPIPELINERUNRESPONSE._serialized_start=570
  _LISTLABELINGPIPELINERUNRESPONSE._serialized_end=737
  _CREATELABELINGPIPELINERUNREQUEST._serialized_start=740
  _CREATELABELINGPIPELINERUNREQUEST._serialized_end=878
  _CREATELABELINGPIPELINERUNRESPONSE._serialized_start=880
  _CREATELABELINGPIPELINERUNRESPONSE._serialized_end=915
  _UPDATELABELINGPIPELINERUNREQUEST._serialized_start=918
  _UPDATELABELINGPIPELINERUNREQUEST._serialized_end=1104
  _UPDATELABELINGPIPELINERUNRESPONSE._serialized_start=1106
  _UPDATELABELINGPIPELINERUNRESPONSE._serialized_end=1141
  _GETLABELINGPIPELINERUNREQUEST._serialized_start=1143
  _GETLABELINGPIPELINERUNREQUEST._serialized_end=1207
  _GETLABELINGPIPELINERUNRESPONSE._serialized_start=1210
  _GETLABELINGPIPELINERUNRESPONSE._serialized_end=1360
  _DELETELABELINGPIPELINERUNREQUEST._serialized_start=1362
  _DELETELABELINGPIPELINERUNREQUEST._serialized_end=1429
  _DELETELABELINGPIPELINERUNRESPONSE._serialized_start=1431
  _DELETELABELINGPIPELINERUNRESPONSE._serialized_end=1466
  _LABELINGPIPELINERUNSERVICE._serialized_start=1469
  _LABELINGPIPELINERUNSERVICE._serialized_end=2911
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/dataset/v1/dataset.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?github.com/metaprov/modelaapi/services/dataset/v1/dataset.proto\x12\x31github.com.metaprov.modelaapi.services.dataset.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xf4\x01\n\x13ListDatasetsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x62\n\x06labels\x18\x02 \x03(\x0b\x32R.github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x84\x01\n\x14ListDatasetsResponse\x12S\n\x08\x64\x61tasets\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DatasetList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc5\x01\n\x11GetDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12`\n\x06labels\x18\x03 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"r\n\x12GetDatasetResponse\x12N\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"f\n\x14\x43reateDatasetRequest\x12N\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"\x17\n\x15\x43reateDatasetResponse\"\x96\x01\n\x14UpdateDatasetRequest\x12N\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x17\n\x15UpdateDatasetResponse\"7\n\x14\x44\x65leteDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteDatasetResponse\"Q\n\x12UploadChunkRequest\x12\r\n\x05\x66name\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\x12\r\n\x05index\x18\x03 \x01(\x05\x12\x0c\n\x04last\x18\x04 \x01(\x08\"0\n\x13UploadChunkResponse\x12\r\n\x05\x66name\x18\x01 \x01(\t\x12\n\n\x02ok\x18\x02 \x01(\x08\"\x8e\x01\n\x1b\x43reateDatasetProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12N\n\x07\x64\x61taset\x18\x03 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"~\n\x1c\x43reateDatasetProfileResponse\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12Q\n\x07profile\x18\x02 \x01(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\"\x9a\x01\n\x1a\x43reateColumnProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03\x63ol\x18\x03 \x01(\t\x12N\n\x07\x64\x61taset\x18\x04 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Dataset\"q\n\x1b\x43reateColumnProfileResponse\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x44\n\x04plot\x18\x02 \x01(\x0b\x32\x36.github.com.metaprov.modelaapi.services.common.v1.Plot\"H\n\x18GetDatasetProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"\x8f\x01\n\x19GetDatasetProfileResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12Q\n\x07profile\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\":\n\x16\x43ompareDatasetsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\"\x8f\x01\n\x17\x43ompareDatasetsResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\x12R\n\x08profiles\x18\x03 \x03(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\":\n\x16GenerateDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\"\x8f\x01\n\x17GenerateDatasetResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\x12R\n\x08profiles\x18\x03 \x03(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\":\n\x16ValidateDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\"\x8f\x01\n\x17ValidateDatasetResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\r\n\x05names\x18\x02 \x03(\t\x12R\n\x08profiles\x18\x03 \x03(\x0b\x32@.github.com.metaprov.modelaapi.services.common.v1.DatasetProfile\"9\n\x16\x44ownloadDatasetRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"&\n\x17\x44ownloadDatasetResponse\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\"J\n\x13GetDatabasesRequest\x12\x1b\n\x13\x63onnectionNamespace\x18\x01 \x01(\t\x12\x16\n\x0e\x63onnectionName\x18\x02 \x01(\t\")\n\x14GetDatabasesResponse\x12\x11\n\tdatabases\x18\x01 \x03(\t\"]\n\x10GetTablesRequest\x12\x1b\n\x13\x63onnectionNamespace\x18\x01 \x01(\t\x12\x16\n\x0e\x63onnectionName\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61tabaseName\x18\x03 \x01(\t\"#\n\x11GetTablesResponse\x12\x0e\n\x06tables\x18\x01 \x03(\t\"k\n\x11\x45xecuteSqlRequest\x12\x1b\n\x13\x63onnectionNamespace\x18\x01 \x01(\t\x12\x16\n\x0e\x63onnectionName\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61tabaseName\x18\x03 \x01(\t\x12\x0b\n\x03sql\x18\x04 \x01(\t\"d\n\x12\x45xecuteSqlResponse\x12N\n\ttableview\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"i\n\x0fSnapshotRequest\x12\x1b\n\x13\x63onnectionNamespace\x18\x01 \x01(\t\x12\x16\n\x0e\x63onnectionName\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61tabaseName\x18\x03 \x01(\t\x12\x0b\n\x03sql\x18\x04 \x01(\t\"0\n\x10SnapshotResponse\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t2\xe4\x19\n\x0e\x44\x61tasetService\x12\xc1\x01\n\x0cListDatasets\x12\x46.github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsRequest\x1aG.github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/datasets/{namespace}\x12\xc2\x01\n\nGetDataset\x12\x44.github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetRequest\x1a\x45.github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/v1/datasets/{namespace}/{name}\x12\xbb\x01\n\rCreateDataset\x12G.github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetRequest\x1aH.github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetResponse\"\x17\x82\xd3\xe4\x93\x02\x11\"\x0c/v1/datasets:\x01*\x12\xf0\x01\n\rUpdateDataset\x12G.github.com.metaprov.modelaapi.services.dataset.v1.UpdateDatasetRequest\x1aH.github.com.metaprov.modelaapi.services.dataset.v1.UpdateDatasetResponse\"L\x82\xd3\xe4\x93\x02\x46\x1a\x41/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:\x01*\x12\xbf\x01\n\rDeleteDataset\x12G.github.com.metaprov.modelaapi.services.dataset.v1.DeleteDatasetRequest\x1aH.github.com.metaprov.modelaapi.services.dataset.v1.DeleteDatasetResponse\"\x1b\x82\xd3\xe4\x93\x02\x15*\x13/v1/datasets/{name}\x12\xda\x01\n\x0f\x43ompareDatasets\x12I.github.com.metaprov.modelaapi.services.dataset.v1.CompareDatasetsRequest\x1aJ.github.com.metaprov.modelaapi.services.dataset.v1.CompareDatasetsResponse\"0\x82\xd3\xe4\x93\x02*\"(/v1/datasets/{namespace}/{names}:compare\x12\xdf\x01\n\x11GetDatasetProfile\x12K.github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetProfileRequest\x1aL.github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetProfileResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/v1/datasets/{namespace}/{name}:profile\x12\xe8\x01\n\x14\x43reateDatasetProfile\x12N.github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetProfileRequest\x1aO.github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetProfileResponse\"/\x82\xd3\xe4\x93\x02)\"\'/v1/datasets/{namespace}/{name}:profile\x12\xe8\x01\n\x13\x43reateColumnProfile\x12M.github.com.metaprov.modelaapi.services.dataset.v1.CreateColumnProfileRequest\x1aN.github.com.metaprov.modelaapi.services.dataset.v1.CreateColumnProfileResponse\"2\x82\xd3\xe4\x93\x02,\"*/v1/datasets/{namespace}/{name}/columnplot\x12\xdb\x01\n\x0fGenerateDataset\x12I.github.com.metaprov.modelaapi.services.dataset.v1.GenerateDatasetRequest\x1aJ.github.com.metaprov.modelaapi.services.dataset.v1.GenerateDatasetResponse\"1\x82\xd3\xe4\x93\x02+\")/v1/datasets/{namespace}/{names}:generate\x12\xdb\x01\n\x0fValidateDataset\x12I.github.com.metaprov.modelaapi.services.dataset.v1.ValidateDatasetRequest\x1aJ.github.com.metaprov.modelaapi.services.dataset.v1.ValidateDatasetResponse\"1\x82\xd3\xe4\x93\x02+\")/v1/datasets/{namespace}/{names}:validate\x12\xda\x01\n\x0f\x44ownloadDataset\x12I.github.com.metaprov.modelaapi.services.dataset.v1.DownloadDatasetRequest\x1aJ.github.com.metaprov.modelaapi.services.dataset.v1.DownloadDatasetResponse\"0\x82\xd3\xe4\x93\x02*\"(/v1/datasets/{namespace}/{name}:download\x12\xe6\x01\n\x0cGetDatabases\x12\x46.github.com.metaprov.modelaapi.services.dataset.v1.GetDatabasesRequest\x1aG.github.com.metaprov.modelaapi.services.dataset.v1.GetDatabasesResponse\"E\x82\xd3\xe4\x93\x02?\x12=/v1/datasets/{connectionNamespace}/{connectionName}:databases\x12\xda\x01\n\tGetTables\x12\x43.github.com.metaprov.modelaapi.services.dataset.v1.GetTablesRequest\x1a\x44.github.com.metaprov.modelaapi.services.dataset.v1.GetTablesResponse\"B\x82\xd3\xe4\x93\x02<\x12:/v1/datasets/{connectionNamespace}/{connectionName}:tables\x12\xe1\x01\n\nExecuteSql\x12\x44.github.com.metaprov.modelaapi.services.dataset.v1.ExecuteSqlRequest\x1a\x45.github.com.metaprov.modelaapi.services.dataset.v1.ExecuteSqlResponse\"F\x82\xd3\xe4\x93\x02@\">/v1/datasets/{connectionNamespace}/{connectionName}:executesqlB3Z1github.com/metaprov/modelaapi/services/dataset/v1b\x06proto3')



_LISTDATASETSREQUEST = DESCRIPTOR.message_types_by_name['ListDatasetsRequest']
_LISTDATASETSREQUEST_LABELSENTRY = _LISTDATASETSREQUEST.nested_types_by_name['LabelsEntry']
_LISTDATASETSRESPONSE = DESCRIPTOR.message_types_by_name['ListDatasetsResponse']
_GETDATASETREQUEST = DESCRIPTOR.message_types_by_name['GetDatasetRequest']
_GETDATASETREQUEST_LABELSENTRY = _GETDATASETREQUEST.nested_types_by_name['LabelsEntry']
_GETDATASETRESPONSE = DESCRIPTOR.message_types_by_name['GetDatasetResponse']
_CREATEDATASETREQUEST = DESCRIPTOR.message_types_by_name['CreateDatasetRequest']
_CREATEDATASETRESPONSE = DESCRIPTOR.message_types_by_name['CreateDatasetResponse']
_UPDATEDATASETREQUEST = DESCRIPTOR.message_types_by_name['UpdateDatasetRequest']
_UPDATEDATASETRESPONSE = DESCRIPTOR.message_types_by_name['UpdateDatasetResponse']
_DELETEDATASETREQUEST = DESCRIPTOR.message_types_by_name['DeleteDatasetRequest']
_DELETEDATASETRESPONSE = DESCRIPTOR.message_types_by_name['DeleteDatasetResponse']
_UPLOADCHUNKREQUEST = DESCRIPTOR.message_types_by_name['UploadChunkRequest']
_UPLOADCHUNKRESPONSE = DESCRIPTOR.message_types_by_name['UploadChunkResponse']
_CREATEDATASETPROFILEREQUEST = DESCRIPTOR.message_types_by_name['CreateDatasetProfileRequest']
_CREATEDATASETPROFILERESPONSE = DESCRIPTOR.message_types_by_name['CreateDatasetProfileResponse']
_CREATECOLUMNPROFILEREQUEST = DESCRIPTOR.message_types_by_name['CreateColumnProfileRequest']
_CREATECOLUMNPROFILERESPONSE = DESCRIPTOR.message_types_by_name['CreateColumnProfileResponse']
_GETDATASETPROFILEREQUEST = DESCRIPTOR.message_types_by_name['GetDatasetProfileRequest']
_GETDATASETPROFILERESPONSE = DESCRIPTOR.message_types_by_name['GetDatasetProfileResponse']
_COMPAREDATASETSREQUEST = DESCRIPTOR.message_types_by_name['CompareDatasetsRequest']
_COMPAREDATASETSRESPONSE = DESCRIPTOR.message_types_by_name['CompareDatasetsResponse']
_GENERATEDATASETREQUEST = DESCRIPTOR.message_types_by_name['GenerateDatasetRequest']
_GENERATEDATASETRESPONSE = DESCRIPTOR.message_types_by_name['GenerateDatasetResponse']
_VALIDATEDATASETREQUEST = DESCRIPTOR.message_types_by_name['ValidateDatasetRequest']
_VALIDATEDATASETRESPONSE = DESCRIPTOR.message_types_by_name['ValidateDatasetResponse']
_DOWNLOADDATASETREQUEST = DESCRIPTOR.message_types_by_name['DownloadDatasetRequest']
_DOWNLOADDATASETRESPONSE = DESCRIPTOR.message_types_by_name['DownloadDatasetResponse']
_GETDATABASESREQUEST = DESCRIPTOR.message_types_by_name['GetDatabasesRequest']
_GETDATABASESRESPONSE = DESCRIPTOR.message_types_by_name['GetDatabasesResponse']
_GETTABLESREQUEST = DESCRIPTOR.message_types_by_name['GetTablesRequest']
_GETTABLESRESPONSE = DESCRIPTOR.message_types_by_name['GetTablesResponse']
_EXECUTESQLREQUEST = DESCRIPTOR.message_types_by_name['ExecuteSqlRequest']
_EXECUTESQLRESPONSE = DESCRIPTOR.message_types_by_name['ExecuteSqlResponse']
_SNAPSHOTREQUEST = DESCRIPTOR.message_types_by_name['SnapshotRequest']
_SNAPSHOTRESPONSE = DESCRIPTOR.message_types_by_name['SnapshotResponse']
ListDatasetsRequest = _reflection.GeneratedProtocolMessageType('ListDatasetsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATASETSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATASETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsRequest)
  })
_sym_db.RegisterMessage(ListDatasetsRequest)
_sym_db.RegisterMessage(ListDatasetsRequest.LabelsEntry)

ListDatasetsResponse = _reflection.GeneratedProtocolMessageType('ListDatasetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASETSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.ListDatasetsResponse)
  })
_sym_db.RegisterMessage(ListDatasetsResponse)

GetDatasetRequest = _reflection.GeneratedProtocolMessageType('GetDatasetRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETDATASETREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _GETDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetRequest)
  })
_sym_db.RegisterMessage(GetDatasetRequest)
_sym_db.RegisterMessage(GetDatasetRequest.LabelsEntry)

GetDatasetResponse = _reflection.GeneratedProtocolMessageType('GetDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetResponse)
  })
_sym_db.RegisterMessage(GetDatasetResponse)

CreateDatasetRequest = _reflection.GeneratedProtocolMessageType('CreateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetRequest)
  })
_sym_db.RegisterMessage(CreateDatasetRequest)

CreateDatasetResponse = _reflection.GeneratedProtocolMessageType('CreateDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetResponse)
  })
_sym_db.RegisterMessage(CreateDatasetResponse)

UpdateDatasetRequest = _reflection.GeneratedProtocolMessageType('UpdateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.UpdateDatasetRequest)
  })
_sym_db.RegisterMessage(UpdateDatasetRequest)

UpdateDatasetResponse = _reflection.GeneratedProtocolMessageType('UpdateDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.UpdateDatasetResponse)
  })
_sym_db.RegisterMessage(UpdateDatasetResponse)

DeleteDatasetRequest = _reflection.GeneratedProtocolMessageType('DeleteDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.DeleteDatasetRequest)
  })
_sym_db.RegisterMessage(DeleteDatasetRequest)

DeleteDatasetResponse = _reflection.GeneratedProtocolMessageType('DeleteDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.DeleteDatasetResponse)
  })
_sym_db.RegisterMessage(DeleteDatasetResponse)

UploadChunkRequest = _reflection.GeneratedProtocolMessageType('UploadChunkRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADCHUNKREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.UploadChunkRequest)
  })
_sym_db.RegisterMessage(UploadChunkRequest)

UploadChunkResponse = _reflection.GeneratedProtocolMessageType('UploadChunkResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPLOADCHUNKRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.UploadChunkResponse)
  })
_sym_db.RegisterMessage(UploadChunkResponse)

CreateDatasetProfileRequest = _reflection.GeneratedProtocolMessageType('CreateDatasetProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASETPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetProfileRequest)
  })
_sym_db.RegisterMessage(CreateDatasetProfileRequest)

CreateDatasetProfileResponse = _reflection.GeneratedProtocolMessageType('CreateDatasetProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASETPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.CreateDatasetProfileResponse)
  })
_sym_db.RegisterMessage(CreateDatasetProfileResponse)

CreateColumnProfileRequest = _reflection.GeneratedProtocolMessageType('CreateColumnProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOLUMNPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.CreateColumnProfileRequest)
  })
_sym_db.RegisterMessage(CreateColumnProfileRequest)

CreateColumnProfileResponse = _reflection.GeneratedProtocolMessageType('CreateColumnProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOLUMNPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.CreateColumnProfileResponse)
  })
_sym_db.RegisterMessage(CreateColumnProfileResponse)

GetDatasetProfileRequest = _reflection.GeneratedProtocolMessageType('GetDatasetProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASETPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetProfileRequest)
  })
_sym_db.RegisterMessage(GetDatasetProfileRequest)

GetDatasetProfileResponse = _reflection.GeneratedProtocolMessageType('GetDatasetProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASETPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetDatasetProfileResponse)
  })
_sym_db.RegisterMessage(GetDatasetProfileResponse)

CompareDatasetsRequest = _reflection.GeneratedProtocolMessageType('CompareDatasetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMPAREDATASETSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.CompareDatasetsRequest)
  })
_sym_db.RegisterMessage(CompareDatasetsRequest)

CompareDatasetsResponse = _reflection.GeneratedProtocolMessageType('CompareDatasetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPAREDATASETSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.CompareDatasetsResponse)
  })
_sym_db.RegisterMessage(CompareDatasetsResponse)

GenerateDatasetRequest = _reflection.GeneratedProtocolMessageType('GenerateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GenerateDatasetRequest)
  })
_sym_db.RegisterMessage(GenerateDatasetRequest)

GenerateDatasetResponse = _reflection.GeneratedProtocolMessageType('GenerateDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATEDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GenerateDatasetResponse)
  })
_sym_db.RegisterMessage(GenerateDatasetResponse)

ValidateDatasetRequest = _reflection.GeneratedProtocolMessageType('ValidateDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.ValidateDatasetRequest)
  })
_sym_db.RegisterMessage(ValidateDatasetRequest)

ValidateDatasetResponse = _reflection.GeneratedProtocolMessageType('ValidateDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.ValidateDatasetResponse)
  })
_sym_db.RegisterMessage(ValidateDatasetResponse)

DownloadDatasetRequest = _reflection.GeneratedProtocolMessageType('DownloadDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.DownloadDatasetRequest)
  })
_sym_db.RegisterMessage(DownloadDatasetRequest)

DownloadDatasetResponse = _reflection.GeneratedProtocolMessageType('DownloadDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.DownloadDatasetResponse)
  })
_sym_db.RegisterMessage(DownloadDatasetResponse)

GetDatabasesRequest = _reflection.GeneratedProtocolMessageType('GetDatabasesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABASESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetDatabasesRequest)
  })
_sym_db.RegisterMessage(GetDatabasesRequest)

GetDatabasesResponse = _reflection.GeneratedProtocolMessageType('GetDatabasesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATABASESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetDatabasesResponse)
  })
_sym_db.RegisterMessage(GetDatabasesResponse)

GetTablesRequest = _reflection.GeneratedProtocolMessageType('GetTablesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetTablesRequest)
  })
_sym_db.RegisterMessage(GetTablesRequest)

GetTablesResponse = _reflection.GeneratedProtocolMessageType('GetTablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.GetTablesResponse)
  })
_sym_db.RegisterMessage(GetTablesResponse)

ExecuteSqlRequest = _reflection.GeneratedProtocolMessageType('ExecuteSqlRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTESQLREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.ExecuteSqlRequest)
  })
_sym_db.RegisterMessage(ExecuteSqlRequest)

ExecuteSqlResponse = _reflection.GeneratedProtocolMessageType('ExecuteSqlResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTESQLRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.ExecuteSqlResponse)
  })
_sym_db.RegisterMessage(ExecuteSqlResponse)

SnapshotRequest = _reflection.GeneratedProtocolMessageType('SnapshotRequest', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.SnapshotRequest)
  })
_sym_db.RegisterMessage(SnapshotRequest)

SnapshotResponse = _reflection.GeneratedProtocolMessageType('SnapshotResponse', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.dataset.v1.dataset_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.dataset.v1.SnapshotResponse)
  })
_sym_db.RegisterMessage(SnapshotResponse)

_DATASETSERVICE = DESCRIPTOR.services_by_name['DatasetService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z1github.com/metaprov/modelaapi/services/dataset/v1'
  _LISTDATASETSREQUEST_LABELSENTRY._options = None
  _LISTDATASETSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _GETDATASETREQUEST_LABELSENTRY._options = None
  _GETDATASETREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _DATASETSERVICE.methods_by_name['ListDatasets']._options = None
  _DATASETSERVICE.methods_by_name['ListDatasets']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/datasets/{namespace}'
  _DATASETSERVICE.methods_by_name['GetDataset']._options = None
  _DATASETSERVICE.methods_by_name['GetDataset']._serialized_options = b'\202\323\344\223\002!\022\037/v1/datasets/{namespace}/{name}'
  _DATASETSERVICE.methods_by_name['CreateDataset']._options = None
  _DATASETSERVICE.methods_by_name['CreateDataset']._serialized_options = b'\202\323\344\223\002\021\"\014/v1/datasets:\001*'
  _DATASETSERVICE.methods_by_name['UpdateDataset']._options = None
  _DATASETSERVICE.methods_by_name['UpdateDataset']._serialized_options = b'\202\323\344\223\002F\032A/v1/datasets/{dataset.metadata.namespace}/{dataset.metadata.name}:\001*'
  _DATASETSERVICE.methods_by_name['DeleteDataset']._options = None
  _DATASETSERVICE.methods_by_name['DeleteDataset']._serialized_options = b'\202\323\344\223\002\025*\023/v1/datasets/{name}'
  _DATASETSERVICE.methods_by_name['CompareDatasets']._options = None
  _DATASETSERVICE.methods_by_name['CompareDatasets']._serialized_options = b'\202\323\344\223\002*\"(/v1/datasets/{namespace}/{names}:compare'
  _DATASETSERVICE.methods_by_name['GetDatasetProfile']._options = None
  _DATASETSERVICE.methods_by_name['GetDatasetProfile']._serialized_options = b'\202\323\344\223\002)\022\'/v1/datasets/{namespace}/{name}:profile'
  _DATASETSERVICE.methods_by_name['CreateDatasetProfile']._options = None
  _DATASETSERVICE.methods_by_name['CreateDatasetProfile']._serialized_options = b'\202\323\344\223\002)\"\'/v1/datasets/{namespace}/{name}:profile'
  _DATASETSERVICE.methods_by_name['CreateColumnProfile']._options = None
  _DATASETSERVICE.methods_by_name['CreateColumnProfile']._serialized_options = b'\202\323\344\223\002,\"*/v1/datasets/{namespace}/{name}/columnplot'
  _DATASETSERVICE.methods_by_name['GenerateDataset']._options = None
  _DATASETSERVICE.methods_by_name['GenerateDataset']._serialized_options = b'\202\323\344\223\002+\")/v1/datasets/{namespace}/{names}:generate'
  _DATASETSERVICE.methods_by_name['ValidateDataset']._options = None
  _DATASETSERVICE.methods_by_name['ValidateDataset']._serialized_options = b'\202\323\344\223\002+\")/v1/datasets/{namespace}/{names}:validate'
  _DATASETSERVICE.methods_by_name['DownloadDataset']._options = None
  _DATASETSERVICE.methods_by_name['DownloadDataset']._serialized_options = b'\202\323\344\223\002*\"(/v1/datasets/{namespace}/{name}:download'
  _DATASETSERVICE.methods_by_name['GetDatabases']._options = None
  _DATASETSERVICE.methods_by_name['GetDatabases']._serialized_options = b'\202\323\344\223\002?\022=/v1/datasets/{connectionNamespace}/{connectionName}:databases'
  _DATASETSERVICE.methods_by_name['GetTables']._options = None
  _DATASETSERVICE.methods_by_name['GetTables']._serialized_options = b'\202\323\344\223\002<\022:/v1/datasets/{connectionNamespace}/{connectionName}:tables'
  _DATASETSERVICE.methods_by_name['ExecuteSql']._options = None
  _DATASETSERVICE.methods_by_name['ExecuteSql']._serialized_options = b'\202\323\344\223\002@\">/v1/datasets/{connectionNamespace}/{connectionName}:executesql'
  _LISTDATASETSREQUEST._serialized_start=345
  _LISTDATASETSREQUEST._serialized_end=589
  _LISTDATASETSREQUEST_LABELSENTRY._serialized_start=544
  _LISTDATASETSREQUEST_LABELSENTRY._serialized_end=589
  _LISTDATASETSRESPONSE._serialized_start=592
  _LISTDATASETSRESPONSE._serialized_end=724
  _GETDATASETREQUEST._serialized_start=727
  _GETDATASETREQUEST._serialized_end=924
  _GETDATASETREQUEST_LABELSENTRY._serialized_start=544
  _GETDATASETREQUEST_LABELSENTRY._serialized_end=589
  _GETDATASETRESPONSE._serialized_start=926
  _GETDATASETRESPONSE._serialized_end=1040
  _CREATEDATASETREQUEST._serialized_start=1042
  _CREATEDATASETREQUEST._serialized_end=1144
  _CREATEDATASETRESPONSE._serialized_start=1146
  _CREATEDATASETRESPONSE._serialized_end=1169
  _UPDATEDATASETREQUEST._serialized_start=1172
  _UPDATEDATASETREQUEST._serialized_end=1322
  _UPDATEDATASETRESPONSE._serialized_start=1324
  _UPDATEDATASETRESPONSE._serialized_end=1347
  _DELETEDATASETREQUEST._serialized_start=1349
  _DELETEDATASETREQUEST._serialized_end=1404
  _DELETEDATASETRESPONSE._serialized_start=1406
  _DELETEDATASETRESPONSE._serialized_end=1429
  _UPLOADCHUNKREQUEST._serialized_start=1431
  _UPLOADCHUNKREQUEST._serialized_end=1512
  _UPLOADCHUNKRESPONSE._serialized_start=1514
  _UPLOADCHUNKRESPONSE._serialized_end=1562
  _CREATEDATASETPROFILEREQUEST._serialized_start=1565
  _CREATEDATASETPROFILEREQUEST._serialized_end=1707
  _CREATEDATASETPROFILERESPONSE._serialized_start=1709
  _CREATEDATASETPROFILERESPONSE._serialized_end=1835
  _CREATECOLUMNPROFILEREQUEST._serialized_start=1838
  _CREATECOLUMNPROFILEREQUEST._serialized_end=1992
  _CREATECOLUMNPROFILERESPONSE._serialized_start=1994
  _CREATECOLUMNPROFILERESPONSE._serialized_end=2107
  _GETDATASETPROFILEREQUEST._serialized_start=2109
  _GETDATASETPROFILEREQUEST._serialized_end=2181
  _GETDATASETPROFILERESPONSE._serialized_start=2184
  _GETDATASETPROFILERESPONSE._serialized_end=2327
  _COMPAREDATASETSREQUEST._serialized_start=2329
  _COMPAREDATASETSREQUEST._serialized_end=2387
  _COMPAREDATASETSRESPONSE._serialized_start=2390
  _COMPAREDATASETSRESPONSE._serialized_end=2533
  _GENERATEDATASETREQUEST._serialized_start=2535
  _GENERATEDATASETREQUEST._serialized_end=2593
  _GENERATEDATASETRESPONSE._serialized_start=2596
  _GENERATEDATASETRESPONSE._serialized_end=2739
  _VALIDATEDATASETREQUEST._serialized_start=2741
  _VALIDATEDATASETREQUEST._serialized_end=2799
  _VALIDATEDATASETRESPONSE._serialized_start=2802
  _VALIDATEDATASETRESPONSE._serialized_end=2945
  _DOWNLOADDATASETREQUEST._serialized_start=2947
  _DOWNLOADDATASETREQUEST._serialized_end=3004
  _DOWNLOADDATASETRESPONSE._serialized_start=3006
  _DOWNLOADDATASETRESPONSE._serialized_end=3044
  _GETDATABASESREQUEST._serialized_start=3046
  _GETDATABASESREQUEST._serialized_end=3120
  _GETDATABASESRESPONSE._serialized_start=3122
  _GETDATABASESRESPONSE._serialized_end=3163
  _GETTABLESREQUEST._serialized_start=3165
  _GETTABLESREQUEST._serialized_end=3258
  _GETTABLESRESPONSE._serialized_start=3260
  _GETTABLESRESPONSE._serialized_end=3295
  _EXECUTESQLREQUEST._serialized_start=3297
  _EXECUTESQLREQUEST._serialized_end=3404
  _EXECUTESQLRESPONSE._serialized_start=3406
  _EXECUTESQLRESPONSE._serialized_end=3506
  _SNAPSHOTREQUEST._serialized_start=3508
  _SNAPSHOTREQUEST._serialized_end=3613
  _SNAPSHOTRESPONSE._serialized_start=3615
  _SNAPSHOTRESPONSE._serialized_end=3663
  _DATASETSERVICE._serialized_start=3666
  _DATASETSERVICE._serialized_end=6966
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.dataproduct.v1 import dataproduct_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2


class DataProductServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListDataProducts = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataproduct.v1.DataProductService/ListDataProducts',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.ListDataProductsRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.ListDataProductsResponse.FromString,
                )
        self.CreateDataProduct = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataproduct.v1.DataProductService/CreateDataProduct',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.CreateDataProductRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.CreateDataProductResponse.FromString,
                )
        self.GetDataProduct = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataproduct.v1.DataProductService/GetDataProduct',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.GetDataProductRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.GetDataProductResponse.FromString,
                )
        self.UpdateDataProduct = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataproduct.v1.DataProductService/UpdateDataProduct',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.UpdateDataProductRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.UpdateDataProductResponse.FromString,
                )
        self.DeleteDataProduct = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.dataproduct.v1.DataProductService/DeleteDataProduct',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.DeleteDataProductRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.DeleteDataProductResponse.FromString,
                )


class DataProductServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListDataProducts(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataProduct(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDataProduct(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateDataProduct(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataProduct(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataProductServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListDataProducts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataProducts,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.ListDataProductsRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.ListDataProductsResponse.SerializeToString,
            ),
            'CreateDataProduct': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataProduct,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.CreateDataProductRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.CreateDataProductResponse.SerializeToString,
            ),
            'GetDataProduct': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDataProduct,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.GetDataProductRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.GetDataProductResponse.SerializeToString,
            ),
            'UpdateDataProduct': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateDataProduct,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.UpdateDataProductRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.UpdateDataProductResponse.SerializeToString,
            ),
            'DeleteDataProduct': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataProduct,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.DeleteDataProductRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.DeleteDataProductResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.dataproduct.v1.DataProductService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DataProductService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListDataProducts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataproduct.v1.DataProductService/ListDataProducts',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.ListDataProductsRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.ListDataProductsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateDataProduct(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataproduct.v1.DataProductService/CreateDataProduct',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.CreateDataProductRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.CreateDataProductResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDataProduct(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataproduct.v1.DataProductService/GetDataProduct',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.GetDataProductRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.GetDataProductResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateDataProduct(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataproduct.v1.DataProductService/UpdateDataProduct',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.UpdateDataProductRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.UpdateDataProductResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataProduct(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.dataproduct.v1.DataProductService/DeleteDataProduct',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.DeleteDataProductRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_dataproduct_dot_v1_dot_dataproduct__pb2.DeleteDataProductResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/datasource/v1/datasource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEgithub.com/metaprov/modelaapi/services/datasource/v1/datasource.proto\x12\x34github.com.metaprov.modelaapi.services.datasource.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"\xfb\x01\n\x15ListDataSourceRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12g\n\x06labels\x18\x02 \x03(\x0b\x32W.github.com.metaprov.modelaapi.services.datasource.v1.ListDataSourceRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n\x16ListDataSourceResponse\x12Y\n\x0b\x64\x61tasources\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSourceList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x14GetDataSourceRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"{\n\x15GetDataSourceResponse\x12T\n\ndatasource\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"\x9f\x01\n\x17UpdateDataSourceRequest\x12T\n\ndatasource\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1a\n\x18UpdateDataSourceResponse\"o\n\x17\x43reateDataSourceRequest\x12T\n\ndatasource\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\"\x1a\n\x18\x43reateDataSourceResponse\":\n\x17\x44\x65leteDataSourceRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteDataSourceResponse\"\xe1\x01\n\x12InferSchemaRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12T\n\ndatasource\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataSource\x12T\n\x08location\x18\x04 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\"g\n\x13InferSchemaResponse\x12P\n\x07\x63olumns\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.ColumnProfile\"\xd4\x01\n\x13GetTableViewRequest\x12\x0e\n\x06tenant\x18\x01 \x01(\t\x12W\n\x0c\x66latfilespec\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.CsvFileSpec\x12T\n\x08location\x18\x03 \x01(\x0b\x32\x42.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.DataLocation\"b\n\x14GetTableViewResponse\x12J\n\x05table\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView2\xfa\x0b\n\x11\x44\x61taSourceService\x12\xd1\x01\n\x0fListDataSources\x12K.github.com.metaprov.modelaapi.services.datasource.v1.ListDataSourceRequest\x1aL.github.com.metaprov.modelaapi.services.datasource.v1.ListDataSourceResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/datasources/{namespace}\x12\xcd\x01\n\x10\x43reateDataSource\x12M.github.com.metaprov.modelaapi.services.datasource.v1.CreateDataSourceRequest\x1aN.github.com.metaprov.modelaapi.services.datasource.v1.CreateDataSourceResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/datasources:\x01*\x12\xd4\x01\n\rGetDataSource\x12J.github.com.metaprov.modelaapi.services.datasource.v1.GetDataSourceRequest\x1aK.github.com.metaprov.modelaapi.services.datasource.v1.GetDataSourceResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/datasources/{namespace}/{name}\x12\x88\x02\n\x10UpdateDataSource\x12M.github.com.metaprov.modelaapi.services.datasource.v1.UpdateDataSourceRequest\x1aN.github.com.metaprov.modelaapi.services.datasource.v1.UpdateDataSourceResponse\"U\x82\xd3\xe4\x93\x02O\x1aJ/v1/datasources/{datasource.metadata.namespace}/{datasource.metadata.name}:\x01*\x12\xdd\x01\n\x10\x44\x65leteDataSource\x12M.github.com.metaprov.modelaapi.services.datasource.v1.DeleteDataSourceRequest\x1aN.github.com.metaprov.modelaapi.services.datasource.v1.DeleteDataSourceResponse\"*\x82\xd3\xe4\x93\x02$*\"/v1/datasources/{namespace}/{name}\x12\xd4\x01\n\x0bInferSchema\x12H.github.com.metaprov.modelaapi.services.datasource.v1.InferSchemaRequest\x1aI.github.com.metaprov.modelaapi.services.datasource.v1.InferSchemaResponse\"0\x82\xd3\xe4\x93\x02*\"(/v1/datasources/{namespace}/{name}:infer\x12\xa7\x01\n\x0cGetTableView\x12I.github.com.metaprov.modelaapi.services.datasource.v1.GetTableViewRequest\x1aJ.github.com.metaprov.modelaapi.services.datasource.v1.GetTableViewResponse\"\x00\x42\x36Z4github.com/metaprov/modelaapi/services/datasource/v1b\x06proto3')



_LISTDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['ListDataSourceRequest']
_LISTDATASOURCEREQUEST_LABELSENTRY = _LISTDATASOURCEREQUEST.nested_types_by_name['LabelsEntry']
_LISTDATASOURCERESPONSE = DESCRIPTOR.message_types_by_name['ListDataSourceResponse']
_GETDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['GetDataSourceRequest']
_GETDATASOURCERESPONSE = DESCRIPTOR.message_types_by_name['GetDataSourceResponse']
_UPDATEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataSourceRequest']
_UPDATEDATASOURCERESPONSE = DESCRIPTOR.message_types_by_name['UpdateDataSourceResponse']
_CREATEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['CreateDataSourceRequest']
_CREATEDATASOURCERESPONSE = DESCRIPTOR.message_types_by_name['CreateDataSourceResponse']
_DELETEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['DeleteDataSourceRequest']
_DELETEDATASOURCERESPONSE = DESCRIPTOR.message_types_by_name['DeleteDataSourceResponse']
_INFERSCHEMAREQUEST = DESCRIPTOR.message_types_by_name['InferSchemaRequest']
_INFERSCHEMARESPONSE = DESCRIPTOR.message_types_by_name['InferSchemaResponse']
_GETTABLEVIEWREQUEST = DESCRIPTOR.message_types_by_name['GetTableViewRequest']
_GETTABLEVIEWRESPONSE = DESCRIPTOR.message_types_by_name['GetTableViewResponse']
ListDataSourceRequest = _reflection.GeneratedProtocolMessageType('ListDataSourceRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTDATASOURCEREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.ListDataSourceRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.ListDataSourceRequest)
  })
_sym_db.RegisterMessage(ListDataSourceRequest)
_sym_db.RegisterMessage(ListDataSourceRequest.LabelsEntry)

ListDataSourceResponse = _reflection.GeneratedProtocolMessageType('ListDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTDATASOURCERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.ListDataSourceResponse)
  })
_sym_db.RegisterMessage(ListDataSourceResponse)

GetDataSourceRequest = _reflection.GeneratedProtocolMessageType('GetDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.GetDataSourceRequest)
  })
_sym_db.RegisterMessage(GetDataSourceRequest)

GetDataSourceResponse = _reflection.GeneratedProtocolMessageType('GetDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.GetDataSourceResponse)
  })
_sym_db.RegisterMessage(GetDataSourceResponse)

UpdateDataSourceRequest = _reflection.GeneratedProtocolMessageType('UpdateDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.UpdateDataSourceRequest)
  })
_sym_db.RegisterMessage(UpdateDataSourceRequest)

UpdateDataSourceResponse = _reflection.GeneratedProtocolMessageType('UpdateDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.UpdateDataSourceResponse)
  })
_sym_db.RegisterMessage(UpdateDataSourceResponse)

CreateDataSourceRequest = _reflection.GeneratedProtocolMessageType('CreateDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.CreateDataSourceRequest)
  })
_sym_db.RegisterMessage(CreateDataSourceRequest)

CreateDataSourceResponse = _reflection.GeneratedProtocolMessageType('CreateDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASOURCERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.CreateDataSourceResponse)
  })
_sym_db.RegisterMessage(CreateDataSourceResponse)

DeleteDataSourceRequest = _reflection.GeneratedProtocolMessageType('DeleteDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASOURCEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.DeleteDataSourceRequest)
  })
_sym_db.RegisterMessage(DeleteDataSourceRequest)

DeleteDataSourceResponse = _reflection.GeneratedProtocolMessageType('DeleteDataSourceResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDATASOURCERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.DeleteDataSourceResponse)
  })
_sym_db.RegisterMessage(DeleteDataSourceResponse)

InferSchemaRequest = _reflection.GeneratedProtocolMessageType('InferSchemaRequest', (_message.Message,), {
  'DESCRIPTOR' : _INFERSCHEMAREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.InferSchemaRequest)
  })
_sym_db.RegisterMessage(InferSchemaRequest)

InferSchemaResponse = _reflection.GeneratedProtocolMessageType('InferSchemaResponse', (_message.Message,), {
  'DESCRIPTOR' : _INFERSCHEMARESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.InferSchemaResponse)
  })
_sym_db.RegisterMessage(InferSchemaResponse)

GetTableViewRequest = _reflection.GeneratedProtocolMessageType('GetTableViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEVIEWREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.GetTableViewRequest)
  })
_sym_db.RegisterMessage(GetTableViewRequest)

GetTableViewResponse = _reflection.GeneratedProtocolMessageType('GetTableViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEVIEWRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.datasource.v1.datasource_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.datasource.v1.GetTableViewResponse)
  })
_sym_db.RegisterMessage(GetTableViewResponse)

_DATASOURCESERVICE = DESCRIPTOR.services_by_name['DataSourceService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/services/datasource/v1'
  _LISTDATASOURCEREQUEST_LABELSENTRY._options = None
  _LISTDATASOURCEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _DATASOURCESERVICE.methods_by_name['ListDataSources']._options = None
  _DATASOURCESERVICE.methods_by_name['ListDataSources']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/datasources/{namespace}'
  _DATASOURCESERVICE.methods_by_name['CreateDataSource']._options = None
  _DATASOURCESERVICE.methods_by_name['CreateDataSource']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/datasources:\001*'
  _DATASOURCESERVICE.methods_by_name['GetDataSource']._options = None
  _DATASOURCESERVICE.methods_by_name['GetDataSource']._serialized_options = b'\202\323\344\223\002$\022\"/v1/datasources/{namespace}/{name}'
  _DATASOURCESERVICE.methods_by_name['UpdateDataSource']._options = None
  _DATASOURCESERVICE.methods_by_name['UpdateDataSource']._serialized_options = b'\202\323\344\223\002O\032J/v1/datasources/{datasource.metadata.namespace}/{datasource.metadata.name}:\001*'
  _DATASOURCESERVICE.methods_by_name['DeleteDataSource']._options = None
  _DATASOURCESERVICE.methods_by_name['DeleteDataSource']._serialized_options = b'\202\323\344\223\002$*\"/v1/datasources/{namespace}/{name}'
  _DATASOURCESERVICE.methods_by_name['InferSchema']._options = None
  _DATASOURCESERVICE.methods_by_name['InferSchema']._serialized_options = b'\202\323\344\223\002*\"(/v1/datasources/{namespace}/{name}:infer'
  _LISTDATASOURCEREQUEST._serialized_start=396
  _LISTDATASOURCEREQUEST._serialized_end=647
  _LISTDATASOURCEREQUEST_LABELSENTRY._serialized_start=602
  _LISTDATASOURCEREQUEST_LABELSENTRY._serialized_end=647
  _LISTDATASOURCERESPONSE._serialized_start=650
  _LISTDATASOURCERESPONSE._serialized_end=790
  _GETDATASOURCEREQUEST._serialized_start=792
  _GETDATASOURCEREQUEST._serialized_end=847
  _GETDATASOURCERESPONSE._serialized_start=849
  _GETDATASOURCERESPONSE._serialized_end=972
  _UPDATEDATASOURCEREQUEST._serialized_start=975
  _UPDATEDATASOURCEREQUEST._serialized_end=1134
  _UPDATEDATASOURCERESPONSE._serialized_start=1136
  _UPDATEDATASOURCERESPONSE._serialized_end=1162
  _CREATEDATASOURCEREQUEST._serialized_start=1164
  _CREATEDATASOURCEREQUEST._serialized_end=1275
  _CREATEDATASOURCERESPONSE._serialized_start=1277
  _CREATEDATASOURCERESPONSE._serialized_end=1303
  _DELETEDATASOURCEREQUEST._serialized_start=1305
  _DELETEDATASOURCEREQUEST._serialized_end=1363
  _DELETEDATASOURCERESPONSE._serialized_start=1365
  _DELETEDATASOURCERESPONSE._serialized_end=1391
  _INFERSCHEMAREQUEST._serialized_start=1394
  _INFERSCHEMAREQUEST._serialized_end=1619
  _INFERSCHEMARESPONSE._serialized_start=1621
  _INFERSCHEMARESPONSE._serialized_end=1724
  _GETTABLEVIEWREQUEST._serialized_start=1727
  _GETTABLEVIEWREQUEST._serialized_end=1939
  _GETTABLEVIEWRESPONSE._serialized_start=1941
  _GETTABLEVIEWRESPONSE._serialized_end=2039
  _DATASOURCESERVICE._serialized_start=2042
  _DATASOURCESERVICE._serialized_end=3572
# @@protoc_insertion_point(module_scope)
